@@ -3,11 +3,11 @@ package App::RPi::EnvUI::Event;
 use Async::Event::Interval;
 use Data::Dumper;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 sub new {
     my ($class, %args) = @_;
-    return bless {%args}, shift;
+    return bless {%args}, $class;
 }
 sub env_to_db {
     my ($self) = @_;
@@ -32,7 +32,7 @@ sub env_action {
     my ($self) = @_;
 
     my $db = App::RPi::EnvUI::DB->new(testing => $self->{testing});
-    my $api = App::RPi::EnvUI::API->evt(testing => $self->{testing});
+    my $api = App::RPi::EnvUI::API->new(testing => $self->{testing});
 
     $api->{db} = $db;
     $self->{db} = $db;
@@ -68,8 +68,8 @@ L<App::RPi::EnvUI>
     my $api = App::RPi::EnvUI::API->new;
     my $events = App::RPi::EnvUI::Event->new;
 
-    my $env_to_db_event  = $events->env_to_db($api);
-    my $env_action_event = $events->env_action($api);
+    my $env_to_db_event  = $events->env_to_db;
+    my $env_action_event = $events->env_action;
 
     $env_to_db_event->start;
     $env_action_event->start;
@@ -79,29 +79,28 @@ L<App::RPi::EnvUI>
 This is a helper module for L<App::RPi::EnvUI>, which contains the scheduled
 asynchronous Perl events on the server side of the webapp.
 
+These events are objects of the L<Async::Event::Interval> class, and run in a
+separate process than the rest of the application.
+
 =head1 METHODS
 
-=head2 new
+=head2 new(%args)
 
-Returns a new C<App::RPi::EnvUI::Event> object.
+Returns a new C<App::RPi::EnvUI::Event> object. The parameters are passed in
+within a hash format.
 
-=head2 env_to_db($api)
+Parameters:
 
-Parameter:
+    testing
 
-    $api
+Optional, Bool: C<0> disables testing mode, C<1> enables it.
 
-Mandatory. An instance of the L<App::RPi::EnvUI::API> class.
+=head2 env_to_db
 
-Returns the event that updates the 'stats' environment database table.
+Returns the event that polls the environment sensors, and updates the C<stats>
+environment database table.
 
-=head2 env_action($api)
-
-Parameter:
-
-    $api
-
-Mandatory. An instance of the L<App::RPi::EnvUI::API> class.
+=head2 env_action
 
 Returns the event that enables/disables the GPIO pins associated with the
 environment.
